@@ -17,7 +17,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 
@@ -260,7 +261,7 @@ workspace_dialog_setup_names_treeview(GtkBuilder *builder,
     gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(ls));
 
     render = gtk_cell_renderer_text_new();
-    col = gtk_tree_view_column_new_with_attributes("", render,
+    col = gtk_tree_view_column_new_with_attributes("#", render,
                                                    "text", COL_NUMBER,
                                                    NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
