@@ -227,10 +227,14 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
     DisplayInfo *display_info;
     ClientCycleData *passdata;
     Client *c, *removed;
+    Client *c2 = NULL;
     eventFilterStatus status;
-    KeyCode cancel;
+    KeyCode cancel, left, right, up, down;
     int key, modifiers;
     gboolean key_pressed, cycling, gone;
+    GList *li;
+    Window mouse_window = 0;
+    XButtonEvent ev;
 
     TRACE ("entering clientCycleEventFilter");
 
@@ -244,6 +248,10 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
     cancel = screen_info->params->keys[KEY_CANCEL].keycode;
+    left = screen_info->params->keys[KEY_LEFT].keycode;
+    right = screen_info->params->keys[KEY_RIGHT].keycode;
+    up = screen_info->params->keys[KEY_UP].keycode;
+    down = screen_info->params->keys[KEY_DOWN].keycode;
     modifiers = (screen_info->params->keys[KEY_CYCLE_WINDOWS].modifier |
                  screen_info->params->keys[KEY_CYCLE_REVERSE_WINDOWS].modifier);
     status = EVENT_FILTER_STOP;
@@ -275,7 +283,6 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
             {
                 if (key_pressed)
                 {
-                    Client *c2 = NULL;
                     key = myScreenGetKeyPressed (screen_info, (XKeyEvent *) xevent);
                     /*
                      * We cannot simply check for key == KEY_CANCEL here because of the
@@ -286,6 +293,22 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
                         c2 = tabwinSelectHead (passdata->tabwin);
                         cycling = FALSE;
                     }
+                    else if (xevent->xkey.keycode == up)
+                    {
+                        c2 = tabwinSelectDelta(passdata->tabwin, -1, 0);
+                    }
+                    else if (xevent->xkey.keycode == down)
+                    {
+                        c2 = tabwinSelectDelta(passdata->tabwin, 1, 0);
+                    }
+                    else if (xevent->xkey.keycode == left)
+                    {
+                        c2 = tabwinSelectDelta(passdata->tabwin, 0, -1);
+                    }
+                    else if (xevent->xkey.keycode == right)
+                    {
+                        c2 = tabwinSelectDelta(passdata->tabwin, -0, 1);
+                    }
                     else if (key == KEY_CYCLE_REVERSE_WINDOWS)
                     {
                         TRACE ("Cycle: previous");
@@ -307,21 +330,6 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
                         cycling = FALSE;
                     }
                 }
-
-                if (cycling)
-                {
-                    if (c)
-                    {
-                        if (passdata->wireframe)
-                        {
-                            wireframeUpdate (c, passdata->wireframe);
-                        }
-                    }
-                    else
-                    {
-                        cycling = FALSE;
-                    }
-                }
             }
             break;
         case KeyRelease:
@@ -338,9 +346,42 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
             }
             break;
         case ButtonPress:
-        case ButtonRelease:
-        case EnterNotify:
-        case MotionNotify:
+            status = EVENT_FILTER_STOP;
+            ev = xevent->xbutton;
+            /* window of the event, we might accept it later */
+            mouse_window = xevent->xbutton.window;
+            if (mouse_window != 0)
+            {
+                /* only accept events for the tab windows */
+                for (li = passdata->tabwin->tabwin_list; li != NULL; li = li->next)
+                {
+                    if (GDK_WINDOW_XID (gtk_widget_get_window (li->data)) == mouse_window)
+                    {
+                        if  (ev.button == Button1)
+                        {
+                            cycling = FALSE;
+                            c = tabwinSelectHoveredWidget (passdata->tabwin);
+                            break;
+                        }
+                        else if  (ev.button == Button4)
+                        {
+                            /* Mouse wheel scroll up */
+                            TRACE ("Cycle: previous");
+                            c2 = tabwinSelectPrev(passdata->tabwin);
+                        }
+                        else if (ev.button == Button5)
+                        {
+                            /* Mouse wheel scroll down */
+                            TRACE ("Cycle: next");
+                            c2 = tabwinSelectNext(passdata->tabwin);
+                        }
+                    }
+                }
+                if (c2)
+                {
+                    c = c2;
+                }
+            }
             break;
         default:
             status = EVENT_FILTER_CONTINUE;
@@ -353,6 +394,24 @@ clientCycleEventFilter (XEvent * xevent, gpointer data)
         gtk_main_quit ();
     }
 
+    if (status == EVENT_FILTER_STOP)
+    {
+        if (cycling)
+        {
+            if (c)
+            {
+                if (passdata->wireframe)
+                {
+                    wireframeUpdate (c, passdata->wireframe);
+                }
+            }
+            else
+            {
+                cycling = FALSE;
+            }
+        }
+    }
+
     return status;
 }
 
@@ -365,6 +424,7 @@ clientCycle (Client * c, XKeyEvent * ev)
     GList *client_list, *selected;
     gboolean g1, g2;
     int key, modifier;
+    Client *c2;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientCycle");
@@ -409,7 +469,8 @@ clientCycle (Client * c, XKeyEvent * ev)
     }
 
     g1 = myScreenGrabKeyboard (screen_info, ev->time);
-    g2 = myScreenGrabPointer (screen_info, LeaveWindowMask,  None, ev->time);
+    g2 = myScreenGrabPointer (screen_info, TRUE, LeaveWindowMask, None, ev->time);
+
 
     if (!g1 || !g2)
     {
@@ -432,6 +493,11 @@ clientCycle (Client * c, XKeyEvent * ev)
     }
     passdata.tabwin = tabwinCreate (&client_list, selected, screen_info->params->cycle_workspaces);
     eventFilterPush (display_info->xfilter, clientCycleEventFilter, &passdata);
+
+    c2 = myScreenGetClientFromWindow (screen_info, GDK_WINDOW_XID (gtk_widget_get_window ( passdata.tabwin->tabwin_list->data)), SEARCH_FRAME);
+    g_message ("%p", c2);
+    clientSetFocus (screen_info, c2, ev->time, NO_FOCUS_FLAG);
+    
     gtk_main ();
     eventFilterPop (display_info->xfilter);
     TRACE ("leaving cycle loop");
