@@ -514,19 +514,19 @@ clientAutoMaximize (Client * c, int full_w, int full_h)
     }
 
     if (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED_HORIZ) &&
-        (frameWidth (c) > full_w))
+        (frameWidth (c) >= full_w))
     {
         TRACE ("The application \"%s\" has requested a window width "
-               "(%u) larger than the actual width available in the workspace (%u), "
+               "(%u) equal or larger than the actual width available in the workspace (%u), "
                "the window will be maximized horizontally.", c->name, frameWidth (c), full_w);
         FLAG_SET (c->flags, CLIENT_FLAG_MAXIMIZED_HORIZ);
     }
 
     if (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED_VERT) &&
-        (frameHeight (c) > full_h))
+        (frameHeight (c) >= full_h))
     {
         TRACE ("The application \"%s\" has requested a window height "
-               "(%u) larger than the actual height available in the workspace (%u), "
+               "(%u) equal or larger than the actual height available in the workspace (%u), "
                "the window will be maximized vertically.", c->name, frameHeight (c), full_h);
         FLAG_SET (c->flags, CLIENT_FLAG_MAXIMIZED_VERT);
     }
