@@ -50,6 +50,10 @@
 #include "compositor.h"
 #include "ui_style.h"
 
+#ifndef WM_EXITING_TIMEOUT
+#define WM_EXITING_TIMEOUT 15 /*seconds */
+#endif
+
 gboolean
 myScreenCheckWMAtom (ScreenInfo *screen_info, Atom atom)
 {
@@ -66,7 +70,9 @@ myScreenCheckWMAtom (ScreenInfo *screen_info, Atom atom)
 static gboolean
 myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
 {
+    const char *wm_name;
     gchar selection[32];
+    gchar *display_name;
     gulong wait, timeout;
     DisplayInfo *display_info;
     XSetWindowAttributes attrs;
@@ -74,6 +80,7 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
     XEvent event;
     Atom wm_sn_atom;
 
+
     g_return_val_if_fail (screen_info, FALSE);
     g_return_val_if_fail (screen_info->display_info, FALSE);
 
@@ -82,13 +89,19 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
     display_info = screen_info->display_info;
     g_snprintf (selection, sizeof (selection), "WM_S%d", screen_info->screen);
     wm_sn_atom = XInternAtom (display_info->dpy, selection, FALSE);
+    display_name = gdk_screen_make_display_name (screen_info->gscr);
+    wm_name = gdk_x11_screen_get_window_manager_name (screen_info->gscr);
 
+    XSync (display_info->dpy, FALSE);
     current_wm = XGetSelectionOwner (display_info->dpy, wm_sn_atom);
     if (current_wm)
     {
         if (!replace_wm)
         {
+            g_message ("Another Window Manager (%s) is already running on screen %s", wm_name, display_name);
             g_message ("To replace the current window manager, try \"--replace\"");
+            g_free (display_name);
+
             return FALSE;
         }
         gdk_error_trap_push ();
@@ -102,15 +115,18 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
 
     if (!setXAtomManagerOwner (display_info, wm_sn_atom, screen_info->xroot, screen_info->xfwm4_win))
     {
-        g_warning ("Cannot acquire window manager selection on screen %d", screen_info->screen);
+        g_warning ("Cannot acquire window manager selection on screen %s", display_name);
+        g_free (display_name);
+
         return FALSE;
     }
 
     /* Waiting for previous window manager to exit */
     if (current_wm)
     {
+        g_print ("Waiting for current window manager (%s) on screen %s to exit:", wm_name, display_name);
         wait = 0;
-        timeout = 10 * G_USEC_PER_SEC;
+        timeout = WM_EXITING_TIMEOUT * G_USEC_PER_SEC;
         while (wait < timeout)
         {
             if (XCheckWindowEvent (display_info->dpy, current_wm, StructureNotifyMask, &event) && (event.type == DestroyNotify))
@@ -119,14 +135,24 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
             }
             g_usleep(G_USEC_PER_SEC / 10);
             wait += G_USEC_PER_SEC / 10;
+            if (wait % G_USEC_PER_SEC == 0)
+            {
+              g_print (".");
+            }
         }
 
         if (wait >= timeout)
         {
-            g_warning("Previous window manager on screen %d is not exiting", screen_info->screen);
+            g_print(" Failed\n");
+            g_warning("Previous window manager (%s) on screen %s is not exiting", wm_name, display_name);
+            g_free (display_name);
+
             return FALSE;
         }
+        g_print(" Done\n");
     }
+    g_free (display_name);
+
     return TRUE;
 }
 
@@ -430,7 +456,7 @@ myScreenGrabKeyboard (ScreenInfo *screen_info, guint32 timestamp)
 }
 
 gboolean
-myScreenGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cursor, guint32 timestamp)
+myScreenGrabPointer (ScreenInfo *screen_info, gboolean owner_events, unsigned int event_mask, Cursor cursor, guint32 timestamp)
 {
     gboolean grab;
 
@@ -442,7 +468,7 @@ myScreenGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cu
     {
         grab = (XGrabPointer (myScreenGetXDisplay (screen_info),
                               screen_info->xroot,
-                              FALSE, event_mask,
+                              owner_events, event_mask,
                               GrabModeAsync, GrabModeAsync,
                               screen_info->xroot,
                               cursor,
@@ -460,7 +486,7 @@ myScreenChangeGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cur
     gboolean grab;
 
     g_return_val_if_fail (screen_info, FALSE);
-    TRACE ("entering myScreenGrabPointer");
+    TRACE ("entering myScreenChangeGrabPointer");
 
     grab = FALSE;
     if (screen_info->pointer_grabs > 0)
@@ -780,7 +806,6 @@ myScreenUpdateFontHeight (ScreenInfo *screen_info)
     PangoFontDescription *desc;
     PangoContext *context;
     PangoFontMetrics *metrics;
-    PangoLanguage *language;
     GtkWidget *widget;
 
     g_return_val_if_fail (screen_info != NULL, FALSE);
@@ -792,8 +817,7 @@ myScreenUpdateFontHeight (ScreenInfo *screen_info)
 
     if (desc && context)
     {
-        language = pango_context_get_language (context);
-        metrics = pango_context_get_metrics (context, desc, language);
+        metrics = pango_context_get_metrics (context, desc, NULL);
         screen_info->font_height =
                  PANGO_PIXELS (pango_font_metrics_get_ascent (metrics) +
                                pango_font_metrics_get_descent (metrics));
