@@ -35,11 +35,19 @@ typedef struct _Tabwin Tabwin;
 typedef struct _TabwinWidget TabwinWidget;
 typedef struct _TabwinWidgetClass TabwinWidgetClass;
 
+typedef enum
+{
+    STANDARD_ICON_GRID,
+    OVERFLOW_COLUMN_GRID,
+}
+CYCLE_TABWIN_MODE;
+
 struct _Tabwin
 {
     GList *tabwin_list;
     GList **client_list;
     GList *selected;
+    GtkWidget *hovered;
     gboolean display_workspace;
 };
 
@@ -51,7 +59,6 @@ struct _TabwinWidget
 
     /* these don't have to be */
     Tabwin *tabwin;
-    GtkWidget *class;
     GtkWidget *label;
     GtkWidget *container;
     GtkWidget *selected;
@@ -76,6 +83,8 @@ Client                  *tabwinSelectHead                       (Tabwin *);
 Client                  *tabwinSelectNext                       (Tabwin *);
 Client                  *tabwinSelectPrev                       (Tabwin *);
 Client                  *tabwinSelectDelta                      (Tabwin *, int, int);
+Client                  *tabwinSelectWidget                     (Tabwin *);
+Client                  *tabwinSelectHoveredWidget              (Tabwin *);
 Client                  *tabwinRemoveClient                     (Tabwin *,
                                                                  Client *);
 void                    tabwinDestroy                           (Tabwin *);
